﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

using Domain.Repositories;

using System.Configuration;
using System.Web.Mvc;
using System.Web.Routing;

using Ninject;
using Ninject.Modules;

namespace FilmsRUsOnline.Plumbing
{
    public class NinjectControllerFactory : DefaultControllerFactory
    {
        // An Ninject "kernel" is the thing that can supply object instances.
        private IKernel kernel = new StandardKernel(new FilmsRUsServices());

        // ASP.NET MVC calls this to get the controller for each request.
        protected override IController GetControllerInstance(RequestContext context, Type controllerType)
        {
            if (controllerType == null)
                return null;
            return (IController)kernel.Get(controllerType);
        }

        // Configures how abstract service types are mapped to concrete implementations.
        private class FilmsRUsServices : NinjectModule
        {
            public override void Load()
            {
                string connStr = ConfigurationManager.ConnectionStrings["FilmsRUsDatabase"].ConnectionString;
                
                // Either inject a real repository...
                Bind<IFilmsRepository>()
                    .To<SqlFilmsRepository>()
                    .WithConstructorArgument("connectionString", connStr);

                // Or inject the dummy repository...
                // Bind<IFilmsRepository>()
                //    .To<DummyFilmsRepository>();
            }
        }
    }
}